@@ -68,6 +68,12 @@ class Event(object):
             returned["status"] = None
             returned["time"] = None
             returned["madechatmod"] = False
+        else:
+            returned["user"] = None
+            returned["text"] = None
+            returned["status"] = None
+            returned["time"] = None
+            returned["madechatmod"] = False
         return returned
 
     @property
@@ -126,7 +132,7 @@ class Client(object):
         content = json.loads(response.content)
         if content['login']['result'] != 'Success':
             print 'Couldn\'t log in: Quitting.'
-            sys.quit(1)
+            sys.exit(1)
 
     def __wikia_request(self, **kwargs):
         request = {}
@@ -176,7 +182,7 @@ class Client(object):
 
     def __come_back(self, settings, xhr):
         xhr_polling = self.__get_code(xhr)
-        extras = json.dumps({'attrs': {'msgType':'command','command':'setstatus','statusState':'away'}})
+        extras = json.dumps({'attrs': {'msgType':'command','command':'setstatus','statusState':'here'}})
         data = self.session.post("http://" + settings["host"] + ":" + settings["port"] + "/socket.io/1/xhr-polling/" + xhr_polling + "?name=" +
             self.username + "&key=" +
             settings['chatkey'] + "&roomId=" + str(settings['room']) + "&t=" + self.__timestamp(),
@@ -223,6 +229,21 @@ class Client(object):
                                 'args': [extras]}))
         return
 
+    def __disconnect(self, settings, xhr, nodisconnect=False):
+        xhr_polling = self.__get_code(xhr)
+        extras = json.dumps({'attrs': {'msgType': 'command','command': 'logout'}})
+        data = self.session.post("http://" + settings["host"] + ":" + settings["port"] + "/socket.io/1/xhr-polling/" +
+                                xhr_polling + "?name=" + self.username + "&key=" + 
+                                settings['chatkey'] + "&roomId=" + str(settings['room']) +
+                                "&t=" + self.__timestamp(),
+                                '5:::' + json.dumps({'name': 'message',
+                                'args': [extras]}))
+        if not nodisconnect:
+            sys.exit(0)
+        return
+
+
+
     def send(self, message):
         self.__send(self.settings, self.xhr, message)
 
@@ -244,6 +265,9 @@ class Client(object):
     def give_chatmod(self, user):
         self.__give_chatmod(self.settings, self.xhr, user, reason)
 
+    def disconnect(self, nodisconnect=False):
+        self.__disconnect(self.settings, self.xhr, nodisconnect=nodisconnect)
+
     def __connection(self, settings, xhr):
         xhr_polling = self.__get_code(xhr)
         time = self.__timestamp()
@@ -254,15 +278,15 @@ class Client(object):
                                 settings['chatkey'] + "&roomId=" +
                                 str(settings['room']) + "&t=" +
                                 time)
-        contents = re.findall(r'({.*?})', data.content)
-        array = []
-        for content in contents:
-            if content:
+        content = re.findall(r'.:::(.*)', data.content)
+        if content:
+            try:
                 loads = json.loads(content[0])
-                array.append(content)
-            else:
-                pass
-        return array
+                return loads
+            except ValueError:
+                return None
+        else:
+            return None
 
     def connection(self):
         var = self.__connection(self.settings, self.xhr)
@@ -305,8 +329,8 @@ class ChatBot(object):
     def start(self):
         in_chat = 0
         while 1:
-            connects = self.c.connection()
-            for connect in connects:
+            connect = self.c.connection()
+            if connect:
                 in_chat += 1
                 e = Event(connect)
                 if in_chat == 1:
@@ -315,6 +339,8 @@ class ChatBot(object):
                     self.on_join(self.c, e)
                 elif connect["event"] == "logout":
                     self.on_leave(self.c, e)
+                elif connect["event"] == "part":
+                    self.on_leave(self.c, e)
                 elif connect["event"] == "updateUser" and connect["data"]["attrs"]["statusState"] == 'away':
                     self.on_away(self.c, e)
                 elif connect["event"] == "updateUser" and connect["data"]["attrs"]["statusState"] == 'here':
